# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..misc import CalculateMedian


def test_CalculateMedian_inputs():
    input_map = dict(
        in_files=dict(),
        median_file=dict(),
        median_per_file=dict(usedefault=True, ),
    )
    inputs = CalculateMedian.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_CalculateMedian_outputs():
    output_map = dict(median_files=dict(), )
    outputs = CalculateMedian.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
